Phylo Module
============

.. currentmodule:: plastro.phylo

The phylo module provides functions for phylogenetic tree construction and analysis.

Core Functions
--------------

.. autosummary::
   :toctree: generated/

   neighbor_joining
   calculate_tree_distances
   bootstrap_tree

Utility Functions
-----------------

.. autosummary::
   :toctree: generated/

   tree_to_newick
   prune_tree
   get_tree_statistics

Function Details
----------------

.. automodule:: plastro.phylo
   :members:
   :undoc-members:
   :show-inheritance: